{% extends 'base.html' %}

{% load i18n %}

{% block title %}{% trans 'Change Password' %}{% endblock %}

{% block content %}
<div class="page-header">
  <h1>{% trans 'Change Password' %}</h1>
</div>

{% include 'form.html' %}
{% endblock %}